@@ -19,8 +19,6 @@
 #
 # Urwid web site: http://excess.org/urwid/
 
-from __future__ import nested_scopes
-
 import sys
 import re
 
@@ -28,7 +26,7 @@ import urwid.html_fragment
 import urwid
 try:
     import templayer
-except:
+except ImportError:
     templayer = None
 
 examples = {}
@@ -128,6 +126,7 @@ def example_edit():
         if fill.body == ask:
             fill.body = urwid.Text( "Nice to meet you,\n"+
                 ask.edit_text+"." )
+            return True
         else:
             raise urwid.ExitMainLoop()
 
@@ -189,6 +188,7 @@ def example_lbcont():
         if not content[position+2:position + 3]:
             content.append(new_question())
         listbox.set_focus(position + 2)
+        return True
 
     loop = urwid.MainLoop(listbox, palette, unhandled_input=update_on_cr)
     loop.run()
@@ -609,18 +609,18 @@ def generate_body(tmpl, sections, blocks, results):
                 # new section -- do its first item next time
                 snum += 1
                 inum = 0
-                t = tmpl.format('toc_section', snum=`snum`,
+                t = tmpl.format('toc_section', snum=repr(snum),
                     name=name )
                 toc_slots[slot].append( t )
-                b = tmpl.format('section_head', snum=`snum`,
+                b = tmpl.format('section_head', snum=repr(snum),
                     name=name )
                 body.append( b )
                 continue
 
             # new item inside a section
             inum += 1
-            t = tmpl.format('toc_item', snum=`snum`, 
-                inum=`inum`, name=name, tag=tag)
+            t = tmpl.format('toc_item', snum=repr(snum), 
+                inum=repr(inum), name=name, tag=tag)
             toc_slots[slot].append( t )
 
             slots = {}
@@ -633,8 +633,8 @@ def generate_body(tmpl, sections, blocks, results):
                 slots['result[%d]'%i] = templayer.RawHTML(res)
                 i += 1
             b = tmpl.format('body[%s]'%tag, ** slots )
-            b = tmpl.format('section_body', snum=`snum`,
-                inum=`inum`, name=name, tag=tag,
+            b = tmpl.format('section_body', snum=repr(snum),
+                inum=repr(inum), name=name, tag=tag,
                 content = b)
             body.append( b )
             
